Input and output
****************

.. currentmodule:: numpy

NPZ files
---------
.. autosummary::
   :toctree: generated/

   load
   save
   savez

Text files
----------
.. autosummary::
   :toctree: generated/

   loadtxt
   savetxt
   genfromtxt
   fromregex
   fromstring
   ndarray.tofile
   ndarray.tolist

String formatting
-----------------
.. autosummary::
   :toctree: generated/

   array_repr
   array_str

Memory mapping files
--------------------
.. autosummary::
   :toctree: generated/

   memmap

Text formatting options
-----------------------
.. autosummary::
   :toctree: generated/

   set_printoptions
   get_printoptions
   set_string_function

Base-n representations
----------------------
.. autosummary::
   :toctree: generated/

   binary_repr
   base_repr

Data sources
------------
.. autosummary::
   :toctree: generated/

   DataSource
